/*
 * Copyright (c) 2011, SRI International .
 * Developed with the sponsorship of the Defense Advanced Research Projects Agency DARPA .
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this data, including any software or models in source or binary form, as well as any drawings, specifications, and documentation collectively "the Data", to deal in the Data without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Data, and to permit persons to whom the Data is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Data .
 *
 * THE DATA IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS, SPONSORS, DEVELOPERS, CONTRIBUTORS, OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE DATA OR THE USE OR OTHER DEALINGS IN THE DATA .
 */
package com.sri.promise.gui;

import javax.swing.*;
import javax.swing.event.MouseInputAdapter;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;

/**
 * @author linda
 */
public final class DragMover extends MouseInputAdapter {

    private final Cursor defCursor;
    private final Cursor hndCursor = Cursor.getPredefinedCursor(Cursor.HAND_CURSOR);
    private final JComponent component;
    private final JViewport viewport;

    private Point last = null;
    private final Point current = new Point();

    public DragMover(JComponent component) {
        this.component = component;
        viewport = (JViewport) component.getParent();
        defCursor = component.getCursor();
        this.component.addMouseListener(this);
        this.component.addMouseMotionListener(this);
    }

    @Override
    public void mouseDragged(final MouseEvent e) {
        current.setLocation(e.getPoint());
        if (last != null && !last.equals(current)) {
            // perform dragging
            Point viewPosition = viewport.getViewPosition();
            viewPosition.translate(last.x - current.x,last.y - current.y);
            component.scrollRectToVisible(new Rectangle(viewPosition, viewport.getSize()));
        }
        last.setLocation(current);
    }

    @Override
    public void mousePressed(MouseEvent e) {
        component.setCursor(hndCursor);
        last = e.getPoint();
        current.setLocation(last);
    }

    @Override
    public void mouseReleased(MouseEvent e) {
        component.setCursor(defCursor);
        last = null;
    }
}
