/*
 * Copyright (c) 2011, SRI International .
 * Developed with the sponsorship of the Defense Advanced Research Projects Agency DARPA .
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this data, including any software or models in source or binary form, as well as any drawings, specifications, and documentation collectively "the Data", to deal in the Data without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Data, and to permit persons to whom the Data is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Data .
 *
 * THE DATA IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS, SPONSORS, DEVELOPERS, CONTRIBUTORS, OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE DATA OR THE USE OR OTHER DEALINGS IN THE DATA .
 */
package com.sri.promise.gui.cmdline;

import com.sri.promise.gui.AnalysisArea;
import com.sri.promise.gui.GraphArea;

import javax.swing.*;
import java.awt.image.BufferedImage;
import java.io.*;
import java.util.Map;

/**
 * Implements a swing worker to generate a graph from a given input string.
 * It uses a number of shell and awk scripts as well as graphviz' dot.
 *
 * @author linda
 */
public final class Grapher extends SwingWorker<BufferedImage, Void> {

    private final String STDIN;
    private final GraphArea graphArea;
    private final AnalysisArea outputArea;

    public Grapher(String STDIN, GraphArea graphArea, AnalysisArea outputArea) {
        this.STDIN = STDIN;
        this.graphArea = graphArea;
        this.outputArea = outputArea;
    }

    @Override
    protected BufferedImage doInBackground() throws Exception {
        // create process for running scripts:
        ProcessBuilder pb = new ProcessBuilder("./graph.sh","-b","-c","none");
        Map<String, String> env = pb.environment();
        env.put("PATH", env.get("PATH") + ":/usr/local/bin"); // for "dot"
        pb.directory(new File("./bin"));
        final Process process = pb.start();
        // echo STDERR from process
        new Thread(new StdErrRedirect(outputArea, process.getErrorStream())).start();
        // start process to grab output of process:
        ImageGrabber grabber = new ImageGrabber(process.getInputStream());
        grabber.start();
        // send text to process standard input:
        PrintWriter writer = new PrintWriter(process.getOutputStream());
        writer.print(STDIN);
        writer.flush();
        writer.close();
        // wait for image grabber to finish:
        grabber.join();
        return grabber.getImage();
    }

    @Override
    protected void done() {
        try {
            graphArea.setGraph(get());
            outputArea.outPrintln("... success generating graph.");
        } catch (Exception ignore) {}
    }
}
