/*
 * Copyright (c) 2011, SRI International .
 * Developed with the sponsorship of the Defense Advanced Research Projects Agency DARPA .
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this data, including any software or models in source or binary form, as well as any drawings, specifications, and documentation collectively "the Data", to deal in the Data without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Data, and to permit persons to whom the Data is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Data .
 *
 * THE DATA IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS, SPONSORS, DEVELOPERS, CONTRIBUTORS, OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE DATA OR THE USE OR OTHER DEALINGS IN THE DATA .
 */
package com.sri.promise.gui.cmdline;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.io.InputStream;
import java.util.logging.Logger;

/**
 * Run this in separate thread to grab the output of the graphing scripts
 * and create a buffered image from it.
 *
 * @author linda
 */
public final class ImageGrabber extends Thread {

    private static final Logger LOGGER = Logger.getLogger(ImageGrabber.class.getName());
    private BufferedImage image = null;
    private final InputStream input;

    public ImageGrabber(InputStream input) {
        this.input = input;
    }

    public void run() {
        try {
            image = ImageIO.read(input);
        } catch (IOException e) {
            LOGGER.severe("Couldn't read image from input stream due to " + e.getMessage());
        }
    }

    public BufferedImage getImage() {
        return image;
    }
}
