/*
 * Copyright (c) 2011, SRI International .
 * Developed with the sponsorship of the Defense Advanced Research Projects Agency DARPA .
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this data, including any software or models in source or binary form, as well as any drawings, specifications, and documentation collectively "the Data", to deal in the Data without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Data, and to permit persons to whom the Data is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Data .
 *
 * THE DATA IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS, SPONSORS, DEVELOPERS, CONTRIBUTORS, OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE DATA OR THE USE OR OTHER DEALINGS IN THE DATA .
 */
package com.sri.promise.gui.cmdline;

import com.sri.promise.gui.AnalysisArea;

import javax.swing.*;
import java.io.*;
import java.util.logging.Logger;

/**
 * @author linda
 */
public final class SchedulerRunner extends SwingWorker<Void, Void> {

    private static final Logger LOGGER = Logger.getLogger(SchedulerRunner.class.getName());

    private final String directory;
    private final AnalysisArea outputArea;
    private final String type;
    private final Integer VLIDs;

    public SchedulerRunner(String directory, AnalysisArea outputArea, String type, Integer vliDs) {
        this.directory = directory;
        this.outputArea = outputArea;
        this.type = type;
        VLIDs = vliDs;
    }

    @Override
    protected Void doInBackground() throws Exception {
        // start run.pl
        ProcessBuilder pb = new ProcessBuilder("./run.pl",type,""+VLIDs);
        pb.directory(new File(directory));
        final Process process = pb.start();

        // echo STDERR from process
        new Thread(new StdErrRedirect(outputArea, process.getErrorStream())).start();

        // start process to grab output of process:
        Thread grabber = new Thread(new Runnable() {
            public void run() {
                BufferedReader reader = new BufferedReader(new InputStreamReader(process.getInputStream()));
                String line;
                try {
                    while ((line = reader.readLine()) != null)
                        outputArea.outPrintln(line);
                } catch (IOException e) {
                    LOGGER.severe("While reading standard output from process: "+e.getMessage()); // stop
                }
            }
        });
        grabber.start();
        grabber.join();

        return null;
    }

    @Override
    protected void done() {
        outputArea.outPrintln("... success running TT scheduler.");
    }
}
