/*
 * Copyright (c) 2011, SRI International .
 * Developed with the sponsorship of the Defense Advanced Research Projects Agency DARPA .
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this data, including any software or models in source or binary form, as well as any drawings, specifications, and documentation collectively "the Data", to deal in the Data without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Data, and to permit persons to whom the Data is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Data .
 *
 * THE DATA IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS, SPONSORS, DEVELOPERS, CONTRIBUTORS, OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE DATA OR THE USE OR OTHER DEALINGS IN THE DATA .
 */
package com.sri.promise.logging;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.text.DateFormat;
import java.util.Date;
import java.util.logging.Formatter;
import java.util.logging.LogRecord;

/**
 * @author linda
 */
public final class FileLogFormatter extends Formatter {

    /**
     * An instance of a DateFormatter that is used for formatting
     * the time of a log record into a human-readable string,
     * according to the rules of the current locale.  The value
     * is set after the first invocation of format, since it is
     * common that a JVM will instantiate a SimpleFormatter without
     * ever using it.
     */
    private DateFormat dateFormat;

    /**
     * Always adding an indent to following lines.
     */
    private static final String lineSep = System.getProperty("line.separator")+"  ";

    @Override
    public String format(LogRecord record) {
        StringBuffer buf = new StringBuffer(180);

        if (dateFormat == null)
            dateFormat = DateFormat.getDateTimeInstance();

        // first line
        buf.append(dateFormat.format(new Date(record.getMillis())));
        buf.append(' ');
        buf.append(record.getSourceClassName());
        buf.append(' ');
        buf.append(record.getSourceMethodName());
        buf.append(lineSep);

        // second line
        buf.append(record.getLevel());
        buf.append(": ");
        buf.append(formatMessage(record));
        buf.append(lineSep);

        Throwable throwable = record.getThrown();
        if (throwable != null) {
            StringWriter sink = new StringWriter();
            throwable.printStackTrace(new PrintWriter(sink, true));
            buf.append(sink.toString());
        } else
            return buf.substring(0, buf.length()-2); // remove the last 2 indents

        return buf.toString();
    }
}
